"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
var MetadataStorage_1 = require("./metadata/MetadataStorage");
var ConstraintMetadata_1 = require("./metadata/ConstraintMetadata");
var ValidationMetadata_1 = require("./metadata/ValidationMetadata");
var ValidationTypes_1 = require("./validation/ValidationTypes");
var Validator_1 = require("./validation/Validator");
// -------------------------------------------------------------------------
// Global Container
// -------------------------------------------------------------------------
/**
 * Container to be used by this library for inversion control. If container was not implicitly set then by default
 * container simply creates a new instance of the given class.
 */
var container = new ((function () {
    function class_1() {
        this.instances = [];
    }
    class_1.prototype.get = function (someClass) {
        if (!this.instances[someClass])
            this.instances[someClass] = new someClass();
        return this.instances[someClass];
    };
    return class_1;
}()))();
/**
 * Sets container to be used by this library.
 *
 * @param iocContainer
 */
function useContainer(iocContainer) {
    container = iocContainer;
}
exports.useContainer = useContainer;
/**
 * Gets the IOC container used by this library.
 */
function getFromContainer(someClass) {
    return container.get(someClass);
}
exports.getFromContainer = getFromContainer;
// -------------------------------------------------------------------------
// Export everything api users needs
// -------------------------------------------------------------------------
__export(require("./decorator/decorators"));
__export(require("./validation/ValidationTypes"));
__export(require("./validation/Validator"));
/**
 * Validates given object by object's decorators or given validation schema.
 */
function validate(schemaNameOrObject, objectOrValidationOptions, maybeValidatorOptions) {
    if (typeof schemaNameOrObject === "string") {
        return getFromContainer(Validator_1.Validator).validate(schemaNameOrObject, objectOrValidationOptions, maybeValidatorOptions);
    }
    else {
        return getFromContainer(Validator_1.Validator).validate(schemaNameOrObject, objectOrValidationOptions);
    }
}
exports.validate = validate;
/**
 * Registers a new validation schema.
 */
function registerSchema(schema) {
    getFromContainer(MetadataStorage_1.MetadataStorage).addValidationSchema(schema);
}
exports.registerSchema = registerSchema;
/**
 * Registers a custom validation decorator.
 */
function registerDecorator(object, propertyName, validationOptions, constraints, validationNameOrConstraintCls, callback, defaultMessageCallback) {
    var constraintCls;
    if (validationNameOrConstraintCls instanceof Function) {
        constraintCls = validationNameOrConstraintCls;
    }
    else {
        constraintCls = (function () {
            function CustomConstraint() {
            }
            CustomConstraint.prototype.validate = function (value, validationArguments) {
                return callback(value, validationArguments);
            };
            CustomConstraint.prototype.defaultMessage = function (validationArguments) {
                if (defaultMessageCallback) {
                    return defaultMessageCallback(validationArguments);
                }
                return "";
            };
            return CustomConstraint;
        }());
        getFromContainer(MetadataStorage_1.MetadataStorage).addConstraintMetadata(new ConstraintMetadata_1.ConstraintMetadata(constraintCls, validationNameOrConstraintCls));
    }
    var validationMetadataArgs = {
        type: ValidationTypes_1.ValidationTypes.CUSTOM_VALIDATION,
        target: object.constructor,
        propertyName: propertyName,
        validationOptions: validationOptions,
        constraintCls: constraintCls,
        constraints: constraints
    };
    getFromContainer(MetadataStorage_1.MetadataStorage).addValidationMetadata(new ValidationMetadata_1.ValidationMetadata(validationMetadataArgs));
}
exports.registerDecorator = registerDecorator;
//# sourceMappingURL=index.js.map