"use strict";
/**
 * Validation types.
 */
var ValidationTypes = (function () {
    function ValidationTypes() {
    }
    /**
     * Checks if validation type is valid.
     */
    ValidationTypes.isValid = function (type) {
        var _this = this;
        return type !== "isValid" &&
            type !== "getMessage" &&
            Object.keys(this).map(function (key) { return _this[key]; }).indexOf(type) !== -1;
    };
    /**
     * Gets default validation error message for the given validation type.
     */
    ValidationTypes.getMessage = function (type) {
        switch (type) {
            /* common checkers */
            case this.IS_DEFINED:
                return "$property is missing, but its required";
            case this.EQUALS:
                return "$property must be equal to $constraint1";
            case this.NOT_EQUALS:
                return "$property should not be equal to $constraint1";
            case this.IS_EMPTY:
                return "$property must be empty";
            case this.IS_NOT_EMPTY:
                return "$property should not be empty";
            case this.IS_IN:
                return "$property must be one of the following values: $constraint1";
            case this.IS_NOT_IN:
                return "$property should not be one of the following values: $constraint1";
            /* type checkers */
            case this.IS_BOOLEAN:
                return "$property must be a boolean value";
            case this.IS_DATE:
                return "$property must be a Date instance";
            case this.IS_NUMBER:
                return "$property must be a number";
            case this.IS_STRING:
                return "$property must be a string";
            case this.IS_DECIMAL:
                return "$property must be a decimal number";
            case this.IS_INT:
                return "$property must be an integer number";
            /* number checkers */
            case this.DIVISIBLE_BY:
                return "$property must be divisible by $constraint1";
            case this.IS_POSITIVE:
                return "$property must be a positive number";
            case this.IS_NEGATIVE:
                return "$property must be a negative number";
            case this.GREATER_THEN:
                return "$property must be greater then $constraint1";
            case this.LESS_THEN:
                return "$property must be less then $constraint1";
            /* date checkers */
            case this.MIN_DATE:
                return "Minimal allowed date for $property is $constraint1";
            case this.MAX_DATE:
                return "Minimal allowed date for $property is $constraint1";
            /* string-as-type checkers */
            case this.IS_BOOLEAN_STRING:
                return "$property must be a boolean string";
            case this.IS_DATE_STRING:
                return "$property must be a date string";
            case this.IS_NUMBER_STRING:
                return "$property must be a number string";
            /* string checkers */
            case this.CONTAINS:
                return "$property must contain a $constraint1 string";
            case this.NOT_CONTAINS:
                return "$property should not contain a $constraint1 string";
            case this.IS_ALPHA:
                return "$property must contain only letters (a-zA-Z)";
            case this.IS_ALPHANUMERIC:
                return "$property must contain only letters and numbers";
            case this.IS_ASCII:
                return "$property must contain only ASCII characters";
            case this.IS_BASE64:
                return "$property must be base64 encoded";
            case this.IS_BYTE_LENGTH:
                return "$property's byte length must fall into ($constraint1, $constraint2) range";
            case this.IS_CREDIT_CARD:
                return "$property must be a credit card";
            case this.IS_CURRENCY:
                return "$property must be a currency";
            case this.IS_EMAIL:
                return "$property must be an email";
            case this.IS_FQDN:
                return "$property must be a valid domain name";
            case this.IS_FULL_WIDTH:
                return "$property must contain a full-width characters";
            case this.IS_HALF_WIDTH:
                return "$property must contain a half-width characters";
            case this.IS_VARIABLE_WIDTH:
                return "$property must contain a full-width and half-width characters";
            case this.IS_HEX_COLOR:
                return "$property must be a hexadecimal color";
            case this.IS_HEXADECIMAL:
                return "$property must be a hexadecimal number";
            case this.IS_IP:
                return "$property must be an ip address";
            case this.IS_ISBN:
                return "$property must be an ISBN";
            case this.IS_ISIN:
                return "$property must be an ISIN (stock/security identifier)";
            case this.IS_ISO8601:
                return "$property must be a valid ISO 8601 date string";
            case this.IS_JSON:
                return "$property must be a json string";
            case this.IS_LOWERCASE:
                return "$property must be a lowercase string";
            case this.IS_MOBILE_PHONE:
                return "$property must be a phone number";
            case this.IS_MONGO_ID:
                return "$property must be a mongodb id";
            case this.IS_MULTIBYTE:
                return "$property must contain one or more multibyte chars";
            case this.IS_SURROGATE_PAIR:
                return "$property must contain any surrogate pairs chars";
            case this.IS_URL:
                return "$property must be an URL address";
            case this.IS_UUID:
                return "$property must be an UUID";
            case this.IS_UPPERCASE:
                return "$property must be uppercase";
            case this.LENGTH:
                return function (args) {
                    var isMinLength = args.constraints[0] !== null && args.constraints[0] !== undefined;
                    var isMaxLength = args.constraints[1] !== null && args.constraints[1] !== undefined;
                    if (isMinLength && (!args.value || args.value.length < args.constraints[0])) {
                        return "$property must be longer then $constraint1";
                    }
                    else if (isMaxLength && (args.value.length > args.constraints[1])) {
                        return "$property must be shorter then $constraint2";
                    }
                    return "$property must be longer then $constraint1 and shorter then $constraint2";
                };
            case this.MIN_LENGTH:
                return "$property must be longer then $constraint1";
            case this.MAX_LENGTH:
                return "$property must be shorter then $constraint2";
            case this.MATCHES:
                return "$property must match $constraint1 regular expression";
            /* array checkers */
            case this.ARRAY_CONTAINS:
                return "$property must contain $constraint1 values";
            case this.ARRAY_NOT_CONTAINS:
                return "$property should not contain $constraint1 values";
            case this.ARRAY_NOT_EMPTY:
                return "$property should not be empty";
            case this.ARRAY_MIN_SIZE:
                return "$property must contain at least $constraint1 elements";
            case this.ARRAY_MAX_SIZE:
                return "$property must contain not more then $constraint1 elements";
            case this.ARRAY_UNIQUE:
                return "All $property's elements must be unique";
        }
    };
    /* system */
    ValidationTypes.CUSTOM_VALIDATION = "custom_validation";
    ValidationTypes.NESTED_VALIDATION = "nested_validation";
    /* common checkers */
    ValidationTypes.IS_DEFINED = "is_defined";
    ValidationTypes.EQUALS = "equal";
    ValidationTypes.NOT_EQUALS = "not_equal";
    ValidationTypes.IS_EMPTY = "is_empty";
    ValidationTypes.IS_NOT_EMPTY = "is_not_empty";
    ValidationTypes.IS_IN = "is_in";
    ValidationTypes.IS_NOT_IN = "is_not_in";
    /* type checkers */
    ValidationTypes.IS_BOOLEAN = "is_boolean";
    ValidationTypes.IS_DATE = "is_date";
    ValidationTypes.IS_NUMBER = "is_number";
    ValidationTypes.IS_STRING = "is_string";
    ValidationTypes.IS_DECIMAL = "is_decimal";
    ValidationTypes.IS_INT = "is_int";
    /* number checkers */
    ValidationTypes.DIVISIBLE_BY = "divisible_by";
    ValidationTypes.IS_POSITIVE = "is_positive";
    ValidationTypes.IS_NEGATIVE = "is_negative";
    ValidationTypes.GREATER_THEN = "greater";
    ValidationTypes.LESS_THEN = "less";
    /* date checkers */
    ValidationTypes.MIN_DATE = "min_date";
    ValidationTypes.MAX_DATE = "max_date";
    /* string-as-type checkers */
    ValidationTypes.IS_BOOLEAN_STRING = "is_boolean_string";
    ValidationTypes.IS_DATE_STRING = "is_date_string";
    ValidationTypes.IS_NUMBER_STRING = "is_number_string";
    /* string checkers */
    ValidationTypes.CONTAINS = "contains";
    ValidationTypes.NOT_CONTAINS = "not_contains";
    ValidationTypes.IS_ALPHA = "is_alpha";
    ValidationTypes.IS_ALPHANUMERIC = "is_alphanumeric";
    ValidationTypes.IS_ASCII = "is_ascii";
    ValidationTypes.IS_BASE64 = "is_base64";
    ValidationTypes.IS_BYTE_LENGTH = "is_byte_length";
    ValidationTypes.IS_CREDIT_CARD = "is_credit_card";
    ValidationTypes.IS_CURRENCY = "is_currency";
    ValidationTypes.IS_EMAIL = "is_email";
    ValidationTypes.IS_FQDN = "is_fqdn";
    ValidationTypes.IS_FULL_WIDTH = "is_full_width";
    ValidationTypes.IS_HALF_WIDTH = "is_half_width";
    ValidationTypes.IS_VARIABLE_WIDTH = "is_variable_width";
    ValidationTypes.IS_HEX_COLOR = "is_hex_color";
    ValidationTypes.IS_HEXADECIMAL = "is_hexadecimal";
    ValidationTypes.IS_IP = "is_ip";
    ValidationTypes.IS_ISBN = "is_isbn";
    ValidationTypes.IS_ISIN = "is_isin";
    ValidationTypes.IS_ISO8601 = "is_iso8601";
    ValidationTypes.IS_JSON = "is_json";
    ValidationTypes.IS_LOWERCASE = "is_lowercase";
    ValidationTypes.IS_MOBILE_PHONE = "is_mobile_phone";
    ValidationTypes.IS_MONGO_ID = "is_mongo_id";
    ValidationTypes.IS_MULTIBYTE = "is_multibyte";
    ValidationTypes.IS_SURROGATE_PAIR = "is_surrogate_pair";
    ValidationTypes.IS_URL = "is_url";
    ValidationTypes.IS_UUID = "is_uuid";
    ValidationTypes.LENGTH = "length";
    ValidationTypes.IS_UPPERCASE = "is_uppercase";
    ValidationTypes.MIN_LENGTH = "min_length";
    ValidationTypes.MAX_LENGTH = "max_length";
    ValidationTypes.MATCHES = "matches";
    /* array checkers */
    ValidationTypes.ARRAY_CONTAINS = "array_contains";
    ValidationTypes.ARRAY_NOT_CONTAINS = "array_not_contains";
    ValidationTypes.ARRAY_NOT_EMPTY = "array_not_empty";
    ValidationTypes.ARRAY_MIN_SIZE = "array_min_size";
    ValidationTypes.ARRAY_MAX_SIZE = "array_max_size";
    ValidationTypes.ARRAY_UNIQUE = "array_unique";
    return ValidationTypes;
}());
exports.ValidationTypes = ValidationTypes;
//# sourceMappingURL=ValidationTypes.js.map